==> qt-creator-opensource-src-4.15.1.zip: qt-creator-opensource-src-4.15.1/src/plugins/conan/conansettings.h <==
/****************************************************************************
**
** Copyright (C) 2021 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include <utils/fileutils.h>

#include <QSettings>

namespace ConanPackageManager {
namespace Internal {

class ConanSettings
{
public:
    ConanSettings() = default;
    void fromSettings(QSettings *settings);
    void toSettings(QSettings *settings) const;

    Utils::FilePath conanFilePath() const { return m_conanFilePath; }

private:
    Utils::FilePath m_conanFilePath;
};

}
}

==> qt-creator-opensource-src-5.0.0.zip: qt-creator-opensource-src-5.0.0/src/plugins/conan/conansettings.h <==
/****************************************************************************
**
** Copyright (C) 2021 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include <utils/aspects.h>
#include <utils/fileutils.h>

#include <QSettings>

namespace ConanPackageManager {
namespace Internal {

class ConanSettings : public Utils::AspectContainer
{
public:
    ConanSettings();

    Utils::StringAspect conanFilePath;
};

} // Internal
} // ConanPackageManager
